"use client";
import React, { useState, useEffect, useCallback } from 'react';
import { useSearchParams } from 'next/navigation';
import Header from '@/components/universal/Header';
import Footer from '@/components/universal/Footer';
import SearchBar from '@/components/property/SearchBar';
import axios from '@/services/APIservices';
import DeveloperPage from '@/components/universal/LandForYou/developerItem';
import AdminPostPage from '@/components/universal/LandForYou/AdminPostPage';
import AgentPostPage from '@/components/universal/LandForYou/AgentPostPage';
import LandownerPostPage from '@/components/universal/LandForYou/LandownerPostPage';

export default function FrontDataPage() {
  const searchParams = useSearchParams();
  const currentView = searchParams.get("view") || "adminPost";

  const [postData, setPostData] = useState({
    agentData: [],
    landownerData: [],
    developerData: []
  });
  const [citiesData, setCitiesData] = useState([]);
  const [error, setError] = useState(null);
  const [citiesError, setCitiesError] = useState(null);
  const [isLoadingCities, setIsLoadingCities] = useState(true);
  const [selectedCity, setSelectedCity] = useState(null);

  const viewComponents = {
    adminPost: AdminPostPage,
    agentPost: AgentPostPage,
    developerPost: DeveloperPage,
    landownerPost: LandownerPostPage
  };

  const SelectedComponent = viewComponents[currentView] || AdminPostPage;

  const fetchCities = useCallback(async () => {
    try {
      const response = await axios.get('/api/post-by-cities');
      if (response.data) {
        const formattedCities = response.data.map(cityData => ({
          name: cityData.city,
          count: cityData.count
        }));
        setCitiesData(formattedCities);
        setCitiesError(null);
      } else {
        throw new Error('Failed to fetch cities data');
      }
    } catch (err) {
      setCitiesError('Error loading cities data');
      console.error('Error fetching cities:', err);
    } finally {
      setIsLoadingCities(false);
    }
  }, []);

  const fetchPostDetails = useCallback(async () => {
    try {
      const response = await axios.get('/api/post-details');

      if (response.data.success) {
        setPostData((prevData) => ({
          ...prevData,
          agentData: response.data.data.agentData || prevData.agentData,
          landownerData: response.data.data.landownerData || prevData.landownerData,
          developerData: response.data.data.developerData || prevData.developerData
        }));
        setError(null);
      } else {
        setError(response.data.message || 'Failed to fetch post details');
      }
    } catch (err) {
      setError(err.response?.data?.message || err.message || 'An error occurred while fetching post details');
    }
  }, []);

  useEffect(() => {
    fetchPostDetails();
    fetchCities();

    const postInterval = setInterval(fetchPostDetails, 5000);
    const citiesInterval = setInterval(fetchCities, 5000);

    return () => {
      clearInterval(postInterval);
      clearInterval(citiesInterval);
    };
  }, [fetchPostDetails, fetchCities]);

  const handleCityClick = (cityName) => {
    setSelectedCity(selectedCity === cityName ? null : cityName);
  };

  const renderCitiesSection = () => {
    if (isLoadingCities) {
      return (
        <div className="flex justify-center items-center h-32">
          <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-brand"></div>
        </div>
      );
    }

    if (citiesError) {
      return (
        <div className="p-4 text-center text-red-500 bg-red-50 rounded-xl">
          {citiesError}
        </div>
      );
    }

    return (
      <div className="grid lg:grid-cols-4 md:grid-cols-3 sm:grid-cols-2 grid-cols-1 border-brand border-[1px] rounded-xl bg-white shadow-lg p-4 gap-2">
        {citiesData.map((city, index) => (
          <button
            key={index}
            onClick={() => handleCityClick(city.name)}
            className={`text-sm p-2 rounded-lg transition-colors duration-200 hover:bg-brand hover:text-white text-center md:text-left ${
              selectedCity === city.name ? 'bg-brand text-white' : 'text-gray-700'
            }`}
          >
            {city.name} ({city.count})
          </button>
        ))}
      </div>
    );
  };

  return (
    <>
      <Header 
        citiesData={citiesData}
        isLoadingCities={isLoadingCities}
        citiesError={citiesError}
      />
      <div className="lg:px-16 md:px-8 sm:px-4 px-2 py-8 bg-[#ededed] min-h-screen">
        <div className="flex gap-2 flex-wrap items-center justify-center md:justify-start mb-4">
          <SearchBar className="w-full md:w-auto" />
          {['Property Type', 'Location', 'Price Range', 'Posted by'].map((filter, index) => (
            <select 
              key={index} 
              className="w-full md:w-auto px-3 py-2 border rounded-lg bg-white shadow-sm text-sm mb-2"
            >
              <option value="">{filter}</option>
            </select>
          ))}
        </div>
        
        <div className="flex lg:flex-row flex-col gap-4">
          <div className="flex-grow flex flex-col gap-8">
            {renderCitiesSection()}
            
            <SelectedComponent 
              agentPostDatas={postData.agentData}
              landownerPostDatas={postData.landownerData}
              developerPostDatas={postData.developerData}
              selectedCity={selectedCity}
            />
          </div>
          
          <div className="lg:w-1/4 w-full">
            <img
              src="/ad.png"
              alt="Advertisement"
              className="w-full rounded-xl shadow-md"
            />
            <p className="text-xl mt-8 font-semibold">Top Articles in Real Estate</p>
            <div className="h-[1px] bg-black mt-2"></div>
            <div className="grid grid-cols-2 gap-2 mt-8">
              {["News 1", "News 2", "News 3", "News 4"].map((item, index) => (
                <div
                  key={index}
                  className="rounded-2xl relative overflow-hidden shadow-md"
                >
                  <img
                    src="/news.png"
                    alt={item}
                    className="w-full h-full object-cover"
                  />
                  <div className="absolute bottom-0 left-0 right-0 bg-black bg-opacity-50 p-2">
                    <p className="text-white text-sm font-semibold">Land Update in</p>
                    <p className="text-white text-xs">Dholera Sir..</p>
                  </div>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
      <Footer />
    </>
  );
}